@@ -31,52 +31,75 @@
 // No direct access
 defined( '_JEXEC' ) or die( 'Restricted access' );
 
-$option = 'com_jobs';
+error_reporting(E_ALL);
+@ini_set('display_errors','1');
 
-if (!JFactory::getUser()->authorise('core.manage', $option))
+if (version_compare(JVERSION, '1.6', 'lt'))
 {
-	return JError::raiseWarning(404, JText::_('JERROR_ALERTNOAUTHOR'));
+	$jacl = JFactory::getACL();
+	$jacl->addACL($option, 'manage', 'users', 'super administrator');
+	$jacl->addACL($option, 'manage', 'users', 'administrator');
+	$jacl->addACL($option, 'manage', 'users', 'manager');
+	
+	// Authorization check
+	$user = JFactory::getUser();
+	if (!$user->authorize($option, 'manage'))
+	{
+		$app = JFactory::getApplication();
+		$app->redirect( 'index.php', JText::_('ALERTNOTAUTH') );
+	}
+}
+else 
+{
+	if (!JFactory::getUser()->authorise('core.manage', $option)) 
+	{
+		return JError::raiseWarning(404, JText::_('JERROR_ALERTNOAUTHOR'));
+	}
 }
 
-// Include scripts
-include_once(JPATH_COMPONENT_ADMINISTRATOR . DS . 'tables' . DS . 'admin.php');
-include_once(JPATH_COMPONENT_ADMINISTRATOR . DS . 'tables' . DS . 'application.php');
-include_once(JPATH_COMPONENT_ADMINISTRATOR . DS . 'tables' . DS . 'category.php');
-include_once(JPATH_COMPONENT_ADMINISTRATOR . DS . 'tables' . DS . 'employer.php');
-include_once(JPATH_COMPONENT_ADMINISTRATOR . DS . 'tables' . DS . 'job.php');
-include_once(JPATH_COMPONENT_ADMINISTRATOR . DS . 'tables' . DS . 'prefs.php');
-include_once(JPATH_COMPONENT_ADMINISTRATOR . DS . 'tables' . DS . 'resume.php');
-include_once(JPATH_COMPONENT_ADMINISTRATOR . DS . 'tables' . DS . 'seeker.php');
-include_once(JPATH_COMPONENT_ADMINISTRATOR . DS . 'tables' . DS . 'shortlist.php');
-include_once(JPATH_COMPONENT_ADMINISTRATOR . DS . 'tables' . DS . 'stats.php');
-include_once(JPATH_COMPONENT_ADMINISTRATOR . DS . 'tables' . DS . 'type.php');
+jimport('joomla.application.component.helper');
+ximport('Hubzero_User');
+ximport('Hubzero_Bank');
 
-include_once(JPATH_COMPONENT_ADMINISTRATOR . DS . 'helpers' . DS . 'permissions.php');
-include_once(JPATH_COMPONENT_ADMINISTRATOR . DS . 'helpers' . DS . 'html.php');
+// Include scripts
+include_once(JPATH_COMPONENT . DS . 'tables' . DS . 'admin.php');
+include_once(JPATH_COMPONENT . DS . 'tables' . DS . 'application.php');
+include_once(JPATH_COMPONENT . DS . 'tables' . DS . 'category.php');
+include_once(JPATH_COMPONENT . DS . 'tables' . DS . 'employer.php');
+include_once(JPATH_COMPONENT . DS . 'tables' . DS . 'job.php');
+include_once(JPATH_COMPONENT . DS . 'tables' . DS . 'prefs.php');
+include_once(JPATH_COMPONENT . DS . 'tables' . DS . 'resume.php');
+include_once(JPATH_COMPONENT . DS . 'tables' . DS . 'seeker.php');
+include_once(JPATH_COMPONENT . DS . 'tables' . DS . 'shortlist.php');
+include_once(JPATH_COMPONENT . DS . 'tables' . DS . 'stats.php');
+include_once(JPATH_COMPONENT . DS . 'tables' . DS . 'type.php');
+
+include_once(JPATH_COMPONENT . DS . 'helpers' . DS . 'jobs.php');
+include_once(JPATH_COMPONENT . DS . 'helpers' . DS . 'html.php');
 
 $controllerName = JRequest::getCmd('controller', 'jobs');
-if (!file_exists(JPATH_COMPONENT_ADMINISTRATOR . DS . 'controllers' . DS . $controllerName . '.php'))
+if (!file_exists(JPATH_COMPONENT . DS . 'controllers' . DS . $controllerName . '.php'))
 {
 	$controllerName = 'jobs';
 }
 
 JSubMenuHelper::addEntry(
-	JText::_('COM_JOBS_JOBS'),
+	JText::_('Jobs'),
 	'index.php?option=com_jobs&controller=jobs',
 	$controllerName == 'jobs'
 );
 JSubMenuHelper::addEntry(
-	JText::_('COM_JOBS_CATEGORIES'),
+	JText::_('Categories'),
 	'index.php?option=com_jobs&controller=categories',
 	$controllerName == 'categories'
 );
 JSubMenuHelper::addEntry(
-	JText::_('COM_JOBS_TYPES'),
+	JText::_('Types'),
 	'index.php?option=com_jobs&controller=types',
 	$controllerName == 'types'
 );
 
-require_once(JPATH_COMPONENT_ADMINISTRATOR . DS . 'controllers' . DS . $controllerName . '.php');
+require_once(JPATH_COMPONENT . DS . 'controllers' . DS . $controllerName . '.php');
 $controllerName = 'JobsController' . ucfirst($controllerName);
 
 // Initiate controller
