@@ -15,22 +15,40 @@
 // no direct access
 defined( '_JEXEC' ) or die('Restricted access');
 
-$option = 'com_poll';
+error_reporting(E_ALL);
+@ini_set('display_errors','1');
 
 // Authorization check
-if (!JFactory::getUser()->authorise('core.manage', $option))
+if (version_compare(JVERSION, '1.6', 'lt'))
 {
-	return JError::raiseWarning(404, JText::_('JERROR_ALERTNOAUTHOR'));
+	$jacl = JFactory::getACL();
+	$jacl->addACL($option, 'manage', 'users', 'super administrator');
+	$jacl->addACL($option, 'manage', 'users', 'administrator');
+	$jacl->addACL($option, 'manage', 'users', 'manager');
+
+	$user = JFactory::getUser();
+	if (!$user->authorize($option, 'manage'))
+	{
+		$app = JFactory::getApplication();
+		$app->redirect('index.php', JText::_('ALERTNOTAUTH'));
+	}
+}
+else 
+{
+	if (!JFactory::getUser()->authorise('core.manage', $option)) 
+	{
+		return JError::raiseWarning(404, JText::_('JERROR_ALERTNOAUTHOR'));
+	}
 }
 
-require_once(JPATH_COMPONENT_ADMINISTRATOR . DS . 'controller.php');
-require_once(JPATH_COMPONENT_ADMINISTRATOR . DS . 'helpers' . DS . 'permissions.php');
+require_once(JPATH_COMPONENT . DS . 'controller.php');
+require_once(JPATH_COMPONENT . DS . 'helpers' . DS . 'poll.php');
 
 // Set the table directory
-JTable::addIncludePath(JPATH_COMPONENT_ADMINISTRATOR . DS . 'tables');
+JTable::addIncludePath(JPATH_COMPONENT . DS . 'tables');
 
 // Create the controller
 $controller	= new PollController();
 
 $controller->execute(JRequest::getCmd('task'));
-$controller->redirect();
+$controller->redirect();
\ No newline at end of file
