@@ -34,13 +34,55 @@ defined('_JEXEC') or die('Restricted access');
 /**
  * Table class for substituting tags for another tag
  */
-class TagsTableSubstitute extends JTable
+class TagsSubstitute extends JTable
 {
+	/**
+	 * int(11)
+	 * 
+	 * @var integer
+	 */
+	var $id         = NULL;
+
+	/**
+	 * varchar(255)
+	 * 
+	 * @var string
+	 */
+	var $tag        = NULL;
+
+	/**
+	 * varchar(255)
+	 * 
+	 * @var string
+	 */
+	var $raw_tag    = NULL;
+
+	/**
+	 * int(11)
+	 * 
+	 * @var integer
+	 */
+	var $tag_id     = NULL;
+
+	/**
+	 * int(11)
+	 * 
+	 * @var integer
+	 */
+	var $created_by = NULL;
+
+	/**
+	 * datetime(0000-00-00 00:00:00)
+	 * 
+	 * @var string
+	 */
+	var $created    = NULL;
+
 	/**
 	 * Constructor
-	 *
-	 * @param   object  &$db  JDatabase
-	 * @return  void
+	 * 
+	 * @param      object &$db JDatabase
+	 * @return     void
 	 */
 	public function __construct(&$db)
 	{
@@ -49,8 +91,8 @@ class TagsTableSubstitute extends JTable
 
 	/**
 	 * Validate data
-	 *
-	 * @return  True if data is valid
+	 * 
+	 * @return     True if data is valid
 	 */
 	public function check()
 	{
@@ -59,7 +101,7 @@ class TagsTableSubstitute extends JTable
 			$this->raw_tag = $this->tag;
 		}
 		$this->raw_tag = trim($this->raw_tag);
-		if (!$this->raw_tag)
+		if (!$this->raw_tag) 
 		{
 			$this->setError(JText::_('You must enter a tag.'));
 			return false;
@@ -67,10 +109,10 @@ class TagsTableSubstitute extends JTable
 
 		$this->tag = $this->normalize($this->raw_tag);
 
-		if (!$this->id)
+		if (!$this->id) 
 		{
-			$juser = JFactory::getUser();
-			$this->created = JFactory::getDate()->toSql();
+			$juser =& JFactory::getUser();
+			$this->created = date('Y-m-d H:i:s', time());  // use gmdate() ?
 			$this->created_by = $juser->get('id');
 		}
 
@@ -86,8 +128,8 @@ class TagsTableSubstitute extends JTable
 	/**
 	 * Inserts a new row if id is zero or updates an existing row in the database table
 	 *
-	 * @param   boolean      $updateNulls  If false, null object variables are not updated
-	 * @return  null|string  null if successful otherwise returns and error message
+	 * @param     boolean $updateNulls If false, null object variables are not updated
+	 * @return    null|string null if successful otherwise returns and error message
 	 */
 	public function store($updateNulls=false)
 	{
@@ -104,15 +146,15 @@ class TagsTableSubstitute extends JTable
 		$result = parent::store($updateNulls);
 		if ($result)
 		{
-			require_once(__DIR__ . DS . 'log.php');
+			require_once(JPATH_ROOT . DS . 'components' . DS . 'com_tags' . DS . 'tables' . DS . 'log.php');
 
 			$data = new stdClass;
-			$data->tag_id  = $this->tag_id;
-			$data->tag     = $this->tag;
+			$data->tag_id = $this->tag_id;
+			$data->tag = $this->tag;
 			$data->raw_tag = $this->raw_tag;
-			$data->id      = $this->$k;
+			$data->id = $this->$k;
 
-			$log = new TagsTableLog($this->_db);
+			$log = new TagsLog($this->_db);
 			$log->log($this->tag_id, $action, json_encode($data));
 		}
 		return $result;
@@ -121,17 +163,16 @@ class TagsTableSubstitute extends JTable
 	/**
 	 * Default delete method
 	 *
-	 * @param   integer  $oid  Entry ID
-	 * @return  boolean  True if successful otherwise returns and error message
+	 * @param      integer $oid Entry ID
+	 * @return     true if successful otherwise returns and error message
 	 */
 	public function delete($oid=null)
 	{
 		$result = parent::delete($oid);
 		if ($result)
 		{
-			require_once(__DIR__ . DS . 'log.php');
-
-			$log = new TagsTableLog($this->_db);
+			require_once(JPATH_ROOT . DS . 'components' . DS . 'com_tags' . DS . 'tables' . DS . 'log.php');
+			$log = new TagsLog($this->_db);
 			$log->log($oid, 'substitute_deleted');
 		}
 		return $result;
@@ -140,9 +181,9 @@ class TagsTableSubstitute extends JTable
 	/**
 	 * Normalize a raw tag
 	 * Strips all non-alphanumeric characters
-	 *
-	 * @param   string  $tag  Raw tag
-	 * @return  string
+	 * 
+	 * @param      string $tag Raw tag
+	 * @return     string
 	 */
 	public function normalize($tag)
 	{
@@ -151,40 +192,42 @@ class TagsTableSubstitute extends JTable
 
 	/**
 	 * Remove all tag references for a given object
-	 *
-	 * @param   integer  $tag_id  Tag ID
-	 * @param   array    $data    List of specific tags to remove (removes all if empty)
-	 * @return  boolean  True if records removed
+	 * 
+	 * @param      integer $tag_id Tag ID
+	 * @param      array   $data   List of specific tags to remove (removes all if empty)
+	 * @return     boolean True if records removed
 	 */
 	public function removeForTag($tag_id=null, $data=array())
 	{
-		$tag_id = $tag_id ?: $this->tag_id;
-
-		if (!$tag_id)
+		if (!$tag_id) 
+		{
+			$tag_id = $this->tag_id;
+		}
+		if (!$tag_id) 
 		{
 			$this->setError(JText::_('Missing argument.'));
 			return false;
 		}
 
-		$sql = "DELETE FROM $this->_tbl WHERE tag_id=" . $this->_db->Quote($tag_id);
+		$sql = "DELETE FROM $this->_tbl WHERE tag_id='$tag_id'";
 		if (count($data) > 0)
 		{
 			$sql .= " AND tag IN ('" . implode("','", $data) . "')";
 		}
 
 		$this->_db->setQuery($sql);
-		if (!$this->_db->query())
+		if (!$this->_db->query()) 
 		{
 			$this->setError($this->_db->getErrorMsg());
 			return false;
 		}
 
-		require_once(__DIR__ . DS . 'log.php');
+		require_once(JPATH_ROOT . DS . 'components' . DS . 'com_tags' . DS . 'tables' . DS . 'log.php');
 
 		$d = new stdClass;
 		$d->tags = $data;
 
-		$log = new TagsTableLog($this->_db);
+		$log = new TagsLog($this->_db);
 		$log->log($tag_id, 'substitute_deleted', json_encode($d));
 
 		return true;
@@ -192,46 +235,50 @@ class TagsTableSubstitute extends JTable
 
 	/**
 	 * Get a record count for a tag ID
-	 *
-	 * @param   integer  $tag_id  Tag ID
-	 * @return  mixed    Integer if successful, false if not
+	 * 
+	 * @param      integer $tag_id Tag ID
+	 * @return     mixed Integer if successful, false if not
 	 */
 	public function getCount($tag_id=null)
 	{
-		$tag_id = $tag_id ?: $this->tag_id;
-
-		if (!$tag_id)
+		if (!$tag_id) 
+		{
+			$tag_id = $this->tag_id;
+		}
+		if (!$tag_id) 
 		{
 			$this->setError(JText::_('Missing argument.'));
 			return false;
 		}
 
-		$this->_db->setQuery("SELECT COUNT(*) FROM $this->_tbl WHERE tag_id=" . $this->_db->Quote($tag_id));
+		$this->_db->setQuery("SELECT COUNT(*) FROM $this->_tbl WHERE tag_id='$tag_id'");
 		return $this->_db->loadResult();
 	}
 
 	/**
 	 * Get all the tags on an object
-	 *
-	 * @param   integer  $tag_id  Tag ID
-	 * @param   integer  $offset  Record offset
-	 * @param   integer  $limit   Number of records to return (returns all if less than 1)
-	 * @return  mixed    Array if successful, false if not
+	 * 
+	 * @param      integer $tag_id Tag ID
+	 * @param      integer $offset Record offset
+	 * @param      integer $limit  Number of records to return (returns all if less than 1)
+	 * @return     mixed Array if successful, false if not
 	 */
 	public function getRecords($tag_id=null, $offset=0, $limit=0)
 	{
-		$tag_id = $tag_id ?: $this->tag_id;
-
-		if (!$tag_id)
+		if (!$tag_id) 
+		{
+			$tag_id = $this->tag_id;
+		}
+		if (!$tag_id) 
 		{
 			$this->setError(JText::_('Missing argument.'));
 			return false;
 		}
 
-		$sql = "SELECT * FROM $this->_tbl WHERE tag_id=" . $this->_db->Quote($tag_id) . " ORDER BY raw_tag ASC";
-		if ($limit > 0)
+		$sql = "SELECT * FROM $this->_tbl WHERE tag_id='$tag_id' ORDER BY raw_tag ASC";
+		if ($limit > 0) 
 		{
-			$sql .= " LIMIT " . intval($offset) . ", " . intval($limit);
+			$sql .= " LIMIT $offset, $limit";
 		}
 
 		$this->_db->setQuery($sql);
@@ -240,16 +287,18 @@ class TagsTableSubstitute extends JTable
 
 	/**
 	 * Get all the tags on an object
-	 *
-	 * @param   integer  $tag_id  Tag ID
-	 * @param   integer  $offset  Record offset
-	 * @param   integer  $limit   Number of records to return (returns all if less than 1)
-	 * @return  string
+	 * 
+	 * @param      integer $tag_id Tag ID
+	 * @param      integer $offset Record offset
+	 * @param      integer $limit  Number of records to return (returns all if less than 1)
+	 * @return     string
 	 */
 	public function getRecordString($tag_id=null, $offset=0, $limit=0)
 	{
+		$items = $this->getRecords($tag_id, $offset, $limit);
+
 		$subs = array();
-		if ($items = $this->getRecords($tag_id, $offset, $limit))
+		if ($items)
 		{
 			foreach ($items as $k => $item)
 			{
@@ -261,39 +310,45 @@ class TagsTableSubstitute extends JTable
 
 	/**
 	 * Move all references to one tag to another tag
-	 *
-	 * @param   integer  $oldtagid  ID of tag to be moved
-	 * @param   integer  $newtagid  ID of tag to move to
-	 * @return  boolean  True if records changed
+	 * 
+	 * @param      integer $oldtagid ID of tag to be moved
+	 * @param      integer $newtagid ID of tag to move to
+	 * @return     boolean True if records changed
 	 */
 	public function moveSubstitutes($oldtagid=null, $newtagid=null)
 	{
-		$oldtagid = $oldtagid ?: $this->tag_id;
-
-		if (!$oldtagid || !$newtagid)
+		if (!$oldtagid) 
+		{
+			$oldtagid = $this->tag_id;
+		}
+		if (!$oldtagid) 
+		{
+			return false;
+		}
+		if (!$newtagid) 
 		{
 			return false;
 		}
 
-		$this->_db->setQuery("SELECT tag FROM $this->_tbl WHERE tag_id=" . $this->_db->Quote($oldtagid));
+		$this->_db->setQuery("SELECT tag FROM $this->_tbl WHERE tag_id='$oldtagid'");
 		$items = $this->_db->loadResultArray();
 
-		$this->_db->setQuery("UPDATE $this->_tbl SET tag_id=" . $this->_db->Quote($newtagid) . " WHERE tag_id=" . $this->_db->Quote($oldtagid));
-		if (!$this->_db->query())
+		$this->_db->setQuery("UPDATE $this->_tbl SET tag_id='$newtagid' WHERE tag_id='$oldtagid'");
+		if (!$this->_db->query()) 
 		{
 			$this->setError($this->_db->getErrorMsg());
 			return false;
 		}
-		else
+		else 
 		{
-			require_once(__DIR__ . DS . 'log.php');
+			require_once(JPATH_ROOT . DS . 'components' . DS . 'com_tags' . DS . 'tables' . DS . 'log.php');
 
 			$data = new stdClass;
-			$data->old_id  = $oldtagid;
-			$data->new_id  = $newtagid;
+			$data->old_id = $oldtagid;
+			$data->new_id = $newtagid;
 			$data->entries = $items;
 
-			$log = new TagsTableLog($this->_db);
+			$log = new TagsLog($this->_db);
 			$log->log($newtagid, 'substitutes_moved', json_encode($data));
 		}
 		return $this->cleanUp($newtagid);
@@ -301,23 +356,25 @@ class TagsTableSubstitute extends JTable
 
 	/**
 	 * Clean up duplicate references
-	 *
-	 * @param   integer  $tag_id  ID of tag to clean up
-	 * @return  boolean  True on success, false if errors
+	 * 
+	 * @param      integer $tag_id ID of tag to clean up
+	 * @return     boolean True on success, false if errors
 	 */
 	public function cleanUp($tag_id=null)
 	{
-		$tag_id = $tag_id ?: $this->tag_id;
-
-		if (!$tag_id)
+		if (!$tag_id) 
+		{
+			$tag_id = $this->tag_id;
+		}
+		if (!$tag_id) 
 		{
 			$this->setError(JText::_('Missing argument.'));
 			return false;
 		}
 
-		$this->_db->setQuery("SELECT * FROM $this->_tbl WHERE tag_id=" . $this->_db->Quote($tag_id) . " ORDER BY id ASC");
+		$this->_db->setQuery("SELECT * FROM $this->_tbl WHERE tag_id='$tag_id' ORDER BY id ASC");
 
-		if ($subs = $this->_db->loadObjectList())
+		if (($subs = $this->_db->loadObjectList()))
 		{
 			$tags = array();
 			foreach ($subs as $sub)
@@ -327,7 +384,7 @@ class TagsTableSubstitute extends JTable
 					// Item isn't in collection yet, so add it
 					$tags[$sub->tag] = $sub->id;
 				}
-				else
+				else 
 				{
 					// Item tag *is* in collection.
 					if ($tags[$sub->tag] == $sub->id)
@@ -335,7 +392,7 @@ class TagsTableSubstitute extends JTable
 						// Really this shouldn't happen
 						continue;
 					}
-					else
+					else 
 					{
 						// Duplcate tag with a different ID!
 						// We don't need duplicates.
