@@ -41,7 +41,7 @@ class Hubzero_Geo
 	 * 
 	 * @return     mixed JDatabase object upon success, null if error
 	 */
-	public static function getGeoDBO()
+	public function getGeoDBO()
 	{
 		static $instance;
 
@@ -63,14 +63,7 @@ class Hubzero_Geo
 				return null;
 			}
 
-			try
-			{
-				$instance = JDatabase::getInstance($options);
-			}
-			catch (Exception $e)
-			{
-				$instance = false;
-			}
+			$instance =& JDatabase::getInstance($options);
 		}
 
 		if (JError::isError($instance)) 
@@ -86,7 +79,7 @@ class Hubzero_Geo
 	 * 
 	 * @return     array
 	 */
-	public static function getcountries()
+	public function getcountries()
 	{
 		$countries = array();
 
@@ -122,7 +115,7 @@ class Hubzero_Geo
 	 * @param      string $continent Parameter description (if any) ...
 	 * @return     array
 	 */
-	public static function getCountriesByContinent($continent='')
+	public function getCountriesByContinent($continent='')
 	{
 		if (!$continent || !($gdb = Hubzero_Geo::getGeoDBO())) 
 		{
@@ -133,75 +126,13 @@ class Hubzero_Geo
 		return $gdb->loadResultArray();
 	}
 
-	/**
-	 * Get continent by the country
-	 * 
-	 * @param      string $country Parameter description (if any) ...
-	 * @return     array
-	 */
-	public static function getContinentByCountry($country='')
-	{
-		if (!$country || !($gdb = Hubzero_Geo::getGeoDBO())) 
-		{
-			return array();
-		}
-
-		$gdb->setQuery("SELECT DISTINCT continent FROM country_continent WHERE LOWER(country) ='" . strtolower($country) . "'");
-		return $gdb->loadResultArray();
-	}
-
-	/**
-	 * Get a list of countries by continent
-	 * 
-	 * @param      array $names Parameter description (if any) ...
-	 * @return     array
-	 */
-	public static function getCodesByNames($names=array())
-	{
-		if (!($gdb = Hubzero_Geo::getGeoDBO())) 
-		{
-			return array();
-		}
-		$names = array_map('strtolower', $names);
-
-		$gdb->setQuery("SELECT DISTINCT name, code FROM countries WHERE LOWER(name) IN ('" . implode("','", $names) . "')");
-		$values = $gdb->loadAssocList('name');
-		if (!is_array($values))
-		{
-			$values = array();
-		}
-		return $values;
-	}
-
 	/**
 	 * Get country based on short code
 	 * 
 	 * @param      string $code Short code (ex: us, de, fr, jp)
 	 * @return     string 
 	 */
-	public static function getCodeByName($name='')
-	{
-		$code = '';
-		if ($name) 
-		{
-			if (!($gdb = Hubzero_Geo::getGeoDBO()))
-			{
-				return $code;
-			}
-
-			$gdb->setQuery("SELECT code FROM countries WHERE LOWER(name) = " . $gdb->Quote(strtolower($name)));
-			$code = stripslashes($gdb->loadResult());
-		}
-		return $code;
-	}
-
-	/**
-	 * Get country based on short code
-	 * 
-	 * @param      string $code Short code (ex: us, de, fr, jp)
-	 * @return     string 
-	 */
-	public static function getcountry($code='')
+	public function getcountry($code='')
 	{
 		$name = '';
 		if ($code) 
@@ -223,7 +154,7 @@ class Hubzero_Geo
 	 * @param      string $ip IP address to look up
 	 * @return     string 
 	 */
-	public static function ipcountry($ip='')
+	public function ipcountry($ip='')
 	{
 		$country = '';
 		if ($ip) 
@@ -246,7 +177,7 @@ class Hubzero_Geo
 	 * @param      string $country Country to check
 	 * @return     boolean True if D1
 	 */
-	public static function is_d1nation($country)
+	public function is_d1nation($country)
 	{
 		$d1nation = false;
 		if ($country) 
@@ -272,7 +203,7 @@ class Hubzero_Geo
 	 * @param      string $country Country to check
 	 * @return     boolean True if E1
 	 */
-	public static function is_e1nation($country)
+	public function is_e1nation($country)
 	{
 		$e1nation = false;
 		if ($country) 
@@ -299,7 +230,7 @@ class Hubzero_Geo
 	 * @param      string $location Location to check in
 	 * @return     boolean True if IP is in the location
 	 */
-	public static function is_iplocation($ip, $location)
+	public function is_iplocation($ip, $location)
 	{
 		$iplocation = false;
 		if ($ip && $location) 
