@@ -59,29 +59,98 @@ defined('_JEXEC') or die('Restricted access');
 
 /**
  * Short description for 'modEventsLatest'
- *
+ * 
  * Long description (if any) ...
  */
-class modEventsLatest extends \Hubzero\Module\Module
+class modEventsLatest
 {
+
 	/**
-	 * Display module output
-	 *
+	 * Description for '_attributes'
+	 * 
+	 * @var array
+	 */
+	private $_attributes = array();
+
+	/**
+	 * Short description for '__construct'
+	 * 
+	 * Long description (if any) ...
+	 * 
+	 * @param      unknown $params Parameter description (if any) ...
+	 * @param      unknown $module Parameter description (if any) ...
 	 * @return     void
 	 */
+	public function __construct($params, $module)
+	{
+		$this->params = $params;
+		$this->module = $module;
+	}
+
+	/**
+	 * Short description for '__set'
+	 * 
+	 * Long description (if any) ...
+	 * 
+	 * @param      unknown $property Parameter description (if any) ...
+	 * @param      unknown $value Parameter description (if any) ...
+	 * @return     void
+	 */
+	public function __set($property, $value)
+	{
+		$this->_attributes[$property] = $value;
+	}
+
+	/**
+	 * Short description for '__get'
+	 * 
+	 * Long description (if any) ...
+	 * 
+	 * @param      unknown $property Parameter description (if any) ...
+	 * @return     array Return description (if any) ...
+	 */
+	public function __get($property)
+	{
+		if (isset($this->_attributes[$property]))
+		{
+			return $this->_attributes[$property];
+		}
+	}
+
+	/**
+	 * Short description for '__isset'
+	 * 
+	 * Long description (if any) ...
+	 * 
+	 * @param      unknown $property Parameter description (if any) ...
+	 * @return     array Return description (if any) ...
+	 */
+	public function __isset($property)
+	{
+		return isset($this->_attributes[$property]);
+	}
+
+	/**
+	 * Short description for 'display'
+	 * 
+	 * Long description (if any) ...
+	 * 
+	 * @return     unknown Return description (if any) ...
+	 */
 	public function display()
 	{
-		$this->css();
+		ximport('Hubzero_Document');
+		Hubzero_Document::addModuleStyleSheet($this->module->module);
 
-		$debug = (defined('JDEBUG') && JDEBUG ? true : false);
+		$juser =& JFactory::getUser();
 
-		if (!$debug && intval($this->params->get('cache', 0)))
+		if (!$juser->get('guest') && intval($this->params->get('cache', 0)))
 		{
-			$cache = JFactory::getCache('callback');
+			$cache =& JFactory::getCache('callback');
 			$cache->setCaching(1);
 			$cache->setLifeTime(intval($this->params->get('cache_time', 900)));
 			$cache->call(array($this, 'run'));
-			echo '<!-- cached ' . JFactory::getDate() . ' -->';
+			echo '<!-- cached ' . date('Y-m-d H:i:s', time()) . ' -->';
 			return;
 		}
 
@@ -89,9 +158,11 @@ class modEventsLatest extends \Hubzero\Module\Module
 	}
 
 	/**
-	 * Generate module output
-	 *
-	 * @return     voif
+	 * Short description for 'run'
+	 * 
+	 * Long description (if any) ...
+	 * 
+	 * @return     unknown Return description (if any) ...
 	 */
 	public function run()
 	{
@@ -100,7 +171,7 @@ class modEventsLatest extends \Hubzero\Module\Module
 		{
 			include_once(JPATH_ROOT . DS . 'components' . DS . 'com_events' . DS . 'helpers' . DS . 'html.php');
 			include_once(JPATH_ROOT . DS . 'components' . DS . 'com_events' . DS . 'helpers' . DS . 'date.php');
-			//include_once(JPATH_ROOT . DS . 'components' . DS . 'com_events' . DS . 'helpers' . DS . 'repeat.php');
+			include_once(JPATH_ROOT . DS . 'components' . DS . 'com_events' . DS . 'helpers' . DS . 'repeat.php');
 		}
 		else
 		{
@@ -111,9 +182,14 @@ class modEventsLatest extends \Hubzero\Module\Module
 		$this->_displayLatestEvents();
 	}
 
+	//-----------
+	// This custom sort compare function compares the start times of events that are refernced by the a & b vars
+
 	/**
-	 * This custom sort compare function compares the start times of events that are refernced by the a & b vars
-	 *
+	 * Short description for 'cmpByStartTime'
+	 * 
+	 * Long description (if any) ...
+	 * 
 	 * @param      object &$a Parameter description (if any) ...
 	 * @param      object &$b Parameter description (if any) ...
 	 * @return     integer Return description (if any) ...
@@ -129,38 +205,48 @@ class modEventsLatest extends \Hubzero\Module\Module
 		return ($aStrtTime > $bStrtTime) ? -1 : 1;
 	}
 
+	//-----------
+	// The function below is essentially the 'ShowEventsByDate' function in the com_events module,
+	// except no actual output is performed.  Rather this function returns an array of references to
+	// $rows within the $rows (ie events) input array which occur on the input '$date'.  This
+	// is determined by the complicated com_event algorithm according to the event's repeatting type.
+
 	/**
-	 * The function below is essentially the 'ShowEventsByDate' function in the com_events module,
-	 * except no actual output is performed.  Rather this function returns an array of references to
-	 * $rows within the $rows (ie events) input array which occur on the input '$date'.  This
-	 * is determined by the complicated com_event algorithm according to the event's repeatting type.
-	 *
+	 * Short description for '_getEventsByDate'
+	 * 
+	 * Long description (if any) ...
+	 * 
 	 * @param      array &$rows Parameter description (if any) ...
 	 * @param      unknown $date Parameter description (if any) ...
 	 * @param      array &$seenThisEvent Parameter description (if any) ...
+	 * @param      unknown $noRepeats Parameter description (if any) ...
 	 * @return     array Return description (if any) ...
 	 */
-	private function _getEventsByDate(&$rows, $date, &$seenThisEvent)
+	private function _getEventsByDate(&$rows, $date, &$seenThisEvent, $noRepeats)
 	{
-		$num_events = count($rows);
-		$new_rows_events = array();
+    	$num_events = count($rows);
+    	$new_rows_events = array();
+
+		$eventCheck = new EventsRepeat;
 
 		if ($num_events > 0)
 		{
 			$year  = date('Y', $date);
-			$month = date('m', $date);
-			$day   = date('d', $date);
+	    	$month = date('m', $date);
+	    	$day   = date('d', $date);
 
 			for ($r = 0; $r < count($rows); $r++)
 			{
 				$row = $rows[$r];
-				if (isset($seenThisEvent[$row->id]))
+				if (isset($seenThisEvent[$row->id]) && $noRepeats)
 				{
 					continue;
 				}
-
-				$seenThisEvent[$row->id] = 1;
-				$new_rows_events[] =& $rows[$r];
+				if ($eventCheck->EventsRepeat($row, $year, $month, $day))
+				{
+					$seenThisEvent[$row->id] = 1;
+					$new_rows_events[] =& $rows[$r];
+				}
 			}
 
 			usort($new_rows_events, array('modEventsLatest','cmpByStartTime'));
@@ -171,21 +257,22 @@ class modEventsLatest extends \Hubzero\Module\Module
 
 	/**
 	 * Short description for '_displayLatestEvents'
-	 *
+	 * 
 	 * Long description (if any) ...
-	 *
+	 * 
 	 * @return     void
 	 */
 	private function _displayLatestEvents()
 	{
-		$database = JFactory::getDBO();
+		$database =& JFactory::getDBO();
 
 		// Get the user GID (used in some queries)
-		$juser = JFactory::getUser();
-		//$gid = $juser->get('gid');
+		$juser =& JFactory::getUser();
+		$gid = $juser->get('gid');
 
 		// Get the site language setting
-		$lang = JFactory::getLanguage();
+		$lang =& JFactory::getLanguage();
+		$Config_lang = $lang->getBackwardLang();
 
 		// Get module parameters
 		$mode              = $this->params->get('mode')                ? abs(intval($this->params->get('mode'))) : 4;
@@ -196,7 +283,9 @@ class modEventsLatest extends \Hubzero\Module\Module
 		$disableTitleStyle = $this->params->get('display_title_style') ? abs(intval($this->params->get('display_title_style'))) : 0;
 		$disableDateStyle  = $this->params->get('display_date_style')  ? abs(intval($this->params->get('display_date_style'))) : 0;
 		$customFormatStr   = $this->params->get('custom_format_str')   ? $this->params->get('custom_format_str') : NULL;
+		$norepeat          = $this->params->get('no_repeat')           ? abs(intval($this->params->get('no_repeat'))) : 0;
 		$charlimit         = $this->params->get('char_limit')          ? abs(intval($this->params->get('char_limit'))) : 150;
+		$announcements     = $this->params->get('announcements')       ? abs(intval($this->params->get('announcements'))) : 0;
 
 		// Can't have a mode greater than 4
 		if ($mode > 4)
@@ -218,6 +307,9 @@ class modEventsLatest extends \Hubzero\Module\Module
 		$startday = $this->params->get('start_day');
 		if (!defined('_CAL_CONF_STARDAY'))
 		{
+	/**
+	 * Description for ''_CAL_CONF_STARDAY''
+	 */
 			define('_CAL_CONF_STARDAY',$startday);
 		}
 
@@ -250,126 +342,129 @@ class modEventsLatest extends \Hubzero\Module\Module
 				//start today
 				$beginDate = date('Y-m-d', mktime(0, 0, 0, date('m'), date('d'), date('Y'))) . ' 00:00:00';
 				// end of this month
-				//$endDate = date('Y-m-d', mktime(0,0,0,date('m')+1,0, date('Y'))) . ' 23:59:59';
+				//$endDate = date('Y-m-d', mktime(0,0,0,date('m')+1,0, date('Y')))." 23:59:59";
 				// end of this year
-				//$endDate = date('Y-m-d', mktime(0, 0, 0, date('m'), 0, date('Y') + 1)) . ' 23:59:59';
-				$endDate = gmdate('Y-m-d', mktime(0, 0, 0, gmdate('m')+1, 0, gmdate('Y'))) . ' 23:59:59';
+				$endDate = date('Y-m-d', mktime(0, 0, 0, date('m'), 0, date('Y') + 1)) . ' 23:59:59';
 				break;
 		}
 
-		// Display events
+		switch ($announcements)
+		{
+			case 2:
+				$ancmnt = "AND #__events.announcement='1'";
+			break;
+			case 1:
+				$ancmnt = "AND #__events.announcement!='1'";
+			break;
+			case 0:
+			default:
+				$ancmnt = "";
+			break;
+		}
+
+		// Display only events that are not announcements
 		$query = "SELECT #__events.* FROM #__events, #__categories as b"
-			. "\nWHERE #__events.catid = b.id "
-			. "\n   AND #__events.state='1'"
+			. "\nWHERE #__events.catid = b.id AND b.access <= $gid AND #__events.access <= $gid AND (#__events.state='1' $ancmnt AND #__events.checked_out='0')"
 			. "\n	AND ((publish_up <= '$todayBegin%' AND publish_down >= '$todayBegin%')"
 			. "\n	OR (publish_up <= '$endDate%' AND publish_down >= '$endDate%')"
 			. "\n   OR (publish_up <= '$endDate%' AND publish_up >= '$todayBegin%')"
 			. "\n   OR (publish_down <= '$endDate%' AND publish_down >= '$todayBegin%'))"
-			. "\n   AND (#__events.scope IS NULL OR #__events.scope=" . $database->quote('event') . ")"
-			. "\nORDER BY publish_up ASC LIMIT $maxEvents";
+			. "\nORDER BY publish_up ASC";
 
 		// Retrieve the list of returned records as an array of objects
 		$database->setQuery($query);
-		$this->events = $database->loadObjectList();
+		$rows = $database->loadObjectList();
 
-		// // Determine the events that occur each day within our range
-		// $events = 0;
-		// $date = mktime(0, 0, 0);
-		// $lastDate = mktime(0, 0, 0, intval(substr($endDate, 5, 2)), intval(substr($endDate, 8, 2)), intval(substr($endDate, 0, 4)));
-		// $i = 0;
+		// Determine the events that occur each day within our range
+		$events = 0;
+		$date = mktime(0, 0, 0);
+		$lastDate = mktime(0, 0, 0, intval(substr($endDate, 5, 2)), intval(substr($endDate, 8, 2)), intval(substr($endDate, 0, 4)));
+		$i = 0;
 
-		// $content  = '';
-		// $seenThisEvent = array();
+		$content  = '';
+		$seenThisEvent = array();
 
-		// if (count($rows))
-		// {
-		// 	while ($date <= $lastDate)
-		// 	{
-		// 		// Get the events for this $date
-		// 		$eventsThisDay = $this->_getEventsByDate($rows, $date, $seenThisEvent);
-		// 		echo '<pre>';
-		// 		print_r($eventsThisDay);
-		// 		echo '</pre>';
-		// 		if (count($eventsThisDay))
-		// 		{
-		// 			// dmcd May 7/04  bug fix to not exceed maxEvents
-		// 			$eventsToAdd = min($maxEvents-$events, count($eventsThisDay));
-		// 			$eventsThisDay = array_slice($eventsThisDay, 0, $eventsToAdd);
-		// 			$eventsByRelDay[$i] = $eventsThisDay;
-		// 			$events += count($eventsByRelDay[$i]);
-		// 		}
-		// 		if ($events >= $maxEvents)
-		// 		{
-		// 			break;
-		// 		}
-		// 		$date = mktime(0, 0, 0, date('m', $date), date('d', $date) + 1, date('Y', $date));
-		// 		$i++;
-		// 	}
-		// }
+		if (count($rows))
+		{
+			while ($date <= $lastDate)
+			{
+				// Get the events for this $date
+				$eventsThisDay = $this->_getEventsByDate($rows, $date, $seenThisEvent, $norepeat);
+				if (count($eventsThisDay))
+				{
+					// dmcd May 7/04  bug fix to not exceed maxEvents
+					$eventsToAdd = min($maxEvents-$events, count($eventsThisDay));
+					$eventsThisDay = array_slice($eventsThisDay, 0, $eventsToAdd);
+					$eventsByRelDay[$i] = $eventsThisDay;
+					$events += count($eventsByRelDay[$i]);
+				}
+				if ($events >= $maxEvents)
+				{
+					break;
+				}
+				$date = mktime(0, 0, 0, date('m', $date), date('d', $date) + 1, date('Y', $date));
+				$i++;
+			}
+		}
 
-		// echo '<pre>';
-		// print_r(this);
-		// echo '</pre>';
+		// Do we actually have any events to display?
+		if ($events < $maxEvents && ($mode==1 || $mode==3))
+		{
+			// Display some recent previous events too up to a total of $maxEvents
+			// Changed by Swaroop to display only events that are not announcements
+			$query = "SELECT #__events.* FROM #__events, #__categories as b"
+				. "\nWHERE #__events.catid = b.id AND b.access <= $gid AND #__events.access <= $gid AND (#__events.state='1' $ancmnt AND #__events.checked_out='0')"
+				. "\n	AND ((publish_up <= '$beginDate%' AND publish_down >= '$beginDate%')"
+				. "\n	OR (publish_up <= '$yesterdayEnd%' AND publish_down >= '$yesterdayEnd%')"
+				. "\n   OR (publish_up <= '$yesterdayEnd%' AND publish_up >= '$beginDate%')"
+				. "\n   OR (publish_down <= '$yesterdayEnd%' AND publish_down >= '$beginDate%'))"
+				. "\n  ORDER BY publish_up DESC";
 
-		// // Do we actually have any events to display?
-		// if ($events < $maxEvents && ($mode==1 || $mode==3))
-		// {
-		// 	// Display some recent previous events too up to a total of $maxEvents
-		// 	// Changed by Swaroop to display only events that are not announcements
-		// 	$query = "SELECT #__events.* FROM #__events, #__categories as b"
-		// 		. "\nWHERE #__events.catid = b.id AND b.access <= $gid AND #__events.access <= $gid AND (#__events.state='1' $ancmnt AND #__events.checked_out='0')"
-		// 		. "\n	AND ((publish_up <= '$beginDate%' AND publish_down >= '$beginDate%')"
-		// 		. "\n	OR (publish_up <= '$yesterdayEnd%' AND publish_down >= '$yesterdayEnd%')"
-		// 		. "\n   OR (publish_up <= '$yesterdayEnd%' AND publish_up >= '$beginDate%')"
-		// 		. "\n   OR (publish_down <= '$yesterdayEnd%' AND publish_down >= '$beginDate%'))"
-		// 		. "\n   AND (#__events.scope IS NULL OR #__events.scope=" . $database->quote('event') . ")"
-		// 		. "\n  ORDER BY publish_up DESC";
+			// Initialise the query in the $database connector
+			// This translates the '#__' prefix into the real database prefix
+			$database->setQuery($query);
 
-		// 	// Initialise the query in the $database connector
-		// 	// This translates the '#__' prefix into the real database prefix
-		// 	$database->setQuery($query);
+			// Retrieve the list of returned records as an array of objects
+			$prows = $database->loadObjectList();
 
-		// 	// Retrieve the list of returned records as an array of objects
-		// 	$prows = $database->loadObjectList();
+			if (count($prows))
+			{
+				// Start from yesterday
+				$date = mktime(23, 59, 59, date('m'), date('d') - 1, date('Y'));
+				$lastDate = mktime(0, 0, 0, intval(substr($beginDate, 5, 2)), intval(substr($beginDate, 8, 2)), intval(substr($beginDate, 0, 4)));
+				$i = -1;
 
-		// 	if (count($prows))
-		// 	{
-		// 		// Start from yesterday
-		// 		$date = mktime(23, 59, 59, date('m'), date('d') - 1, date('Y'));
-		// 		$lastDate = mktime(0, 0, 0, intval(substr($beginDate, 5, 2)), intval(substr($beginDate, 8, 2)), intval(substr($beginDate, 0, 4)));
-		// 		$i = -1;
+				while ($date >= $lastDate)
+				{
+					// Get the events for this $date
+					$eventsThisDay = $this->_getEventsByDate($prows, $date, $seenThisEvent, $norepeat);
+					if (count($eventsThisDay))
+					{
+						$eventsByRelDay[$i] = $eventsThisDay;
+						$events += count($eventsByRelDay[$i]);
+					}
+					if ($events >= $maxEvents)
+					{
+						break;
+					}
+					$date = mktime(0, 0, 0, date('m', $date), date('d', $date) - 1, date('Y', $date));
+					$i--;
+				}
+			}
+		}
 
-		// 		while ($date >= $lastDate)
-		// 		{
-		// 			// Get the events for this $date
-		// 			$eventsThisDay = $this->_getEventsByDate($prows, $date, $seenThisEvent, $norepeat);
-		// 			if (count($eventsThisDay))
-		// 			{
-		// 				$eventsByRelDay[$i] = $eventsThisDay;
-		// 				$events += count($eventsByRelDay[$i]);
-		// 			}
-		// 			if ($events >= $maxEvents)
-		// 			{
-		// 				break;
-		// 			}
-		// 			$date = mktime(0, 0, 0, date('m', $date), date('d', $date) - 1, date('Y', $date));
-		// 			$i--;
-		// 		}
-		// 	}
-		// }
+		if (isset($eventsByRelDay) && count($eventsByRelDay))
+		{
+			// Now to display these events, we just start at the smallest index of the $eventsByRelDay array and work our way up.
+			ksort($eventsByRelDay, SORT_NUMERIC);
+			reset($eventsByRelDay);
 
-		// if (isset($eventsByRelDay) && count($eventsByRelDay))
-		// {
-		// 	// Now to display these events, we just start at the smallest index of the $eventsByRelDay array and work our way up.
-		// 	ksort($eventsByRelDay, SORT_NUMERIC);
-		// 	reset($eventsByRelDay);
-
-		// 	$this->eventsByRelDay = $eventsByRelDay;
-		// }
-		// else
-		// {
-		// 	$this->eventsByRelDay = null;
-		// }
+			$this->eventsByRelDay = $eventsByRelDay;
+		}
+		else
+		{
+			$this->eventsByRelDay = null;
+		}
 
 		require(JModuleHelper::getLayoutPath($this->module->module));
 	}
