@@ -34,5 +34,5 @@ defined('_JEXEC') or die('Restricted access');
 // Include the logic only once
 require_once(dirname(__FILE__) . DS . 'helper.php');
 
-$modtoptags = new modTopTags($params, $module);
+$modtoptags = new modTopTags($params);
 $modtoptags->display();
