@@ -31,35 +31,43 @@
 // Check to ensure this file is included in Joomla!
 defined('_JEXEC') or die('Restricted access');
 
+jimport('joomla.plugin.plugin');
 jimport('joomla.filesystem.file');
 
 /**
  * Citations plugin class for bibtex
  */
-class plgCitationDefault extends \Hubzero\Plugin\Plugin
+class plgCitationDefault extends JPlugin
 {
 	/**
-	 * Affects constructor behavior. If true, language files will be loaded automatically.
-	 *
-	 * @var    boolean
+	 * Constructor
+	 * 
+	 * @param      object &$subject The object to observe
+	 * @param      array  $config   An optional associative array of configuration settings.
+	 * @return     void
 	 */
-	protected $_autoloadLanguage = true;
+	public function __construct(&$subject, $config)
+	{
+		parent::__construct($subject, $config);
+
+		$this->loadLanguage();
+	}
 
 	/**
 	 * Return file type
-	 *
+	 * 
 	 * @return     string HTML
 	 */
 	public function onImportAcceptedFiles()
 	{
-		//return '.txt <small>(' . JText::_('PLG_CITATION_DEFAULT_FILE') . ')</small>';
+		return '.txt <small>(Text File)</small>';
 	}
 
 	/**
 	 * Short description for 'onImport'
-	 *
+	 * 
 	 * Long description (if any) ...
-	 *
+	 * 
 	 * @param      array $file Parameter description (if any) ...
 	 * @return     mixed Return description (if any) ...
 	 */
@@ -72,7 +80,7 @@ class plgCitationDefault extends \Hubzero\Plugin\Plugin
 		$file_info = pathinfo($file['name']);
 
 		//only process acceptable files
-		if (!in_array($file_info['extension'], $acceptable))
+		if (!in_array($file_info['extension'], $acceptable)) 
 		{
 			return;
 		}
@@ -81,11 +89,11 @@ class plgCitationDefault extends \Hubzero\Plugin\Plugin
 		$raw_contents = file_get_contents($file['tmp_name']);
 
 		//check to see if this is endnote content
-		if (preg_match('/%A|%0|%T/', $raw_contents))
+		if (preg_match('/%A|%0|%T/', $raw_contents)) 
 		{
 			//load citation import plugins
 			JPluginHelper::importPlugin('citation');
-	        $dispatcher = JDispatcher::getInstance();
+	        $dispatcher =& JDispatcher::getInstance();
 
 			//make new file to pass to dispatcher
 			$new_file = array(
